Struct StopOrderTicket

pub struct StopOrderTicket<T: MoveType> {
    pub id: UID,
    pub gas: Balance<SUI>,
    pub account_id: u64,
    pub encrypted_details: MoveVec<u8>,
    /* private fields */
}
Object that allows to place one order on behalf of the user, used to offer stop limit or market orders. A stop order is an order that is placed only if the index price respects certain conditions, like being above or below a certain price.

Only the Account owner can mint this object and can decide who is going to be the recipient of the ticket. This allows users to run their own stop orders bots eventually, but it’s mainly used to allow 3rd parties to offer such a service (the user is required to trust such 3rd party). The object is intended to be sent to a multisig wallet owned by both the 3rd party and the user. The object is not transferable, stopping the 3rd party from transferring it away, and can be destroyed in any moment only by the user. The user needs to trust the 3rd party for liveness of the service offered.

The order details are encrypted offchain and the result is stored in the ticket. The user needs to share such details with the 3rd party only.

Fields

id: UIDgas: Balance<SUI>

Gas coin that must be provided by the user to cover for one stop order cost.

account_id: u64

Account id for user

encrypted_details: MoveVec<u8>

Vector containing the blake2b hash obtained by the offchain application of blake2b on the following parameters:

  • clearing_house_id: ID
  • expire_timestamp: u64
  • is_limit_order: true if limit order, false if market order
  • stop_index_price: u256
  • ge_stop_index_price: true means the order can be placed when oracle index price is >= than chosen stop_index_price
  • side: bool
  • size: u64
  • price: u64 (can be set at random value if is_limit_order is false)
  • order_type: u64 (can be set at random value if is_limit_order is false)
  • reduce_only: bool
  • salt: vector

Implementations

Source

impl<T: MoveType> StopOrderTicket<T>

pub fn new( id: UID, gas: Balance<SUI>, account_id: u64, encrypted_details: MoveVec<u8>, ) -> Self

Constructs a new StopOrderTicket.

Source

impl<T: MoveType> StopOrderTicket<T>

pub fn move_instance( self, address: Address, t: <T as MoveType>::TypeTag, ) -> MoveInstance<Self>

pub fn type_( address: Address, t: <T as MoveType>::TypeTag, ) -> StopOrderTicketTypeTag<T>