pub struct SessionSummary {
pub base_filled_ask: IFixed,
pub base_filled_bid: IFixed,
pub quote_filled_ask: IFixed,
pub quote_filled_bid: IFixed,
pub base_posted_ask: IFixed,
pub base_posted_bid: IFixed,
pub mark_price: IFixed,
pub bad_debt: IFixed,
}Fields
base_filled_ask: IFixedbase_filled_bid: IFixedquote_filled_ask: IFixedquote_filled_bid: IFixedbase_posted_ask: IFixedbase_posted_bid: IFixedmark_price: IFixedThis would be the mark_price used in the eventuality the session contains a liquidation.
Set at 0 in case there is no liquidation in the session.
bad_debt: IFixedImplementations
Sourceimpl SessionSummary
impl SessionSummary
pub fn move_instance(self, address: Address) -> MoveInstance<Self>
pub fn type_(address: Address) -> SessionSummaryTypeTag