pub struct CoreParams {
pub base_pfs_id: ID,
pub collateral_pfs_id: ID,
pub base_pfs_source_id: ID,
pub collateral_pfs_source_id: ID,
pub base_pfs_tolerance: u64,
pub collateral_pfs_tolerance: u64,
pub lot_size: u64,
pub tick_size: u64,
pub scaling_factor: IFixed,
pub collateral_haircut: IFixed,
pub margin_ratio_initial: IFixed,
pub margin_ratio_maintenance: IFixed,
}Fields
base_pfs_id: IDIdentifier of the base asset’s price feed storage.
collateral_pfs_id: IDIdentifier of the collateral asset’s price feed storage.
base_pfs_source_id: IDIdentifier of the base asset’s price feed storage source id (pyth, stork, etc…).
collateral_pfs_source_id: IDIdentifier of the collateral asset’s price feed storage source id (pyth, stork, etc…).
base_pfs_tolerance: u64Timestamp tolerance for base oracle price
collateral_pfs_tolerance: u64Timestamp tolerance for collateral oracle price
lot_size: u64Number of base units exchanged per lot
tick_size: u64Number of quote units exchanged per tick
scaling_factor: IFixedScaling factor to use to convert collateral units to ifixed values and viceversa
collateral_haircut: IFixedValue haircut applied to collateral allocated in the position. Example: 98%
margin_ratio_initial: IFixedMinimum margin ratio for opening a new position.
margin_ratio_maintenance: IFixedMargin ratio below which full liquidations can occur.
Implementations
Sourceimpl CoreParams
impl CoreParams
Sourcepub fn new(
base_pfs_id: ID,
collateral_pfs_id: ID,
base_pfs_source_id: ID,
collateral_pfs_source_id: ID,
base_pfs_tolerance: u64,
collateral_pfs_tolerance: u64,
lot_size: u64,
tick_size: u64,
scaling_factor: IFixed,
collateral_haircut: IFixed,
margin_ratio_initial: IFixed,
margin_ratio_maintenance: IFixed,
) -> Self
pub fn new( base_pfs_id: ID, collateral_pfs_id: ID, base_pfs_source_id: ID, collateral_pfs_source_id: ID, base_pfs_tolerance: u64, collateral_pfs_tolerance: u64, lot_size: u64, tick_size: u64, scaling_factor: IFixed, collateral_haircut: IFixed, margin_ratio_initial: IFixed, margin_ratio_maintenance: IFixed, ) -> Self
Constructs a new CoreParams.
Sourceimpl CoreParams
impl CoreParams
pub fn move_instance(self, address: Address) -> MoveInstance<Self>
pub fn type_(address: Address) -> CoreParamsTypeTag