pub struct FeesParams {
pub maker_fee: IFixed,
pub taker_fee: IFixed,
pub liquidation_fee: IFixed,
pub force_cancel_fee: IFixed,
pub insurance_fund_fee: IFixed,
pub gas_price_taker_fee: IFixed,
}Fields
maker_fee: IFixedProportion of volume charged as fees from makers upon processing fill events.
taker_fee: IFixedProportion of volume charged as fees from takers after processing fill events.
liquidation_fee: IFixedProportion of volume charged as fees from liquidatees
force_cancel_fee: IFixedProportion of volume charged as fees from liquidatees after forced cancelling of pending orders during liquidation.
insurance_fund_fee: IFixedProportion of volume charged as fees from liquidatees to deposit into insurance fund
gas_price_taker_fee: IFixedAdditional taker fee to apply in case the gas price set for the transaction violates the z-score constraint
Implementations
Sourceimpl FeesParams
impl FeesParams
Sourceimpl FeesParams
impl FeesParams
pub fn move_instance(self, address: Address) -> MoveInstance<Self>
pub fn type_(address: Address) -> FeesParamsTypeTag