pub struct MarketState {
pub cum_funding_rate_long: IFixed,
pub cum_funding_rate_short: IFixed,
pub funding_last_upd_ms: u64,
pub premium_twap: IFixed,
pub premium_twap_last_upd_ms: u64,
pub spread_twap: IFixed,
pub spread_twap_last_upd_ms: u64,
pub gas_price_mean: IFixed,
pub gas_price_variance: IFixed,
pub gas_price_last_upd_ms: u64,
pub open_interest: IFixed,
pub fees_accrued: IFixed,
}Expand description
The state of a perpetuals market.
Fields
cum_funding_rate_long: IFixedThe latest cumulative funding premium in this market for longs. Must be updated periodically.
cum_funding_rate_short: IFixedThe latest cumulative funding premium in this market for shorts. Must be updated periodically.
funding_last_upd_ms: u64The timestamp (millisec) of the latest cumulative funding premium update (both longs and shorts).
The last calculated funding premium TWAP (used for funding settlement).
The timestamp (millisec) of the last update of premium_twap.
spread_twap: IFixedThe last calculated spread TWAP (used for liquidations). Spread is (book - index).
spread_twap_last_upd_ms: u64The timestamp (millisec) of spread_twap last update.
gas_price_mean: IFixedGas price TWAP mean. It is used to calculate the penalty to add to taker fees based on the Z-score of the current gas price relative to the smoothed mean and variance.
gas_price_variance: IFixedGas price TWAP variance. It is used to calculate the penalty to add to taker fees based on the Z-score of the current gas price relative to the smoothed mean and variance.
gas_price_last_upd_ms: u64The timestamp (millisec) of the last update of gas_price_mean and gas_price_variance.
open_interest: IFixedOpen interest (in base tokens) as a fixed-point number. Counts the total size of contracts as the sum of all long positions.
fees_accrued: IFixedTotal amount of fees accrued by this market (in T’s units) Only admin can withdraw these fees.
Implementations
Sourceimpl MarketState
impl MarketState
Sourcepub fn unrealized_funding(&self, pos: &Position) -> IFixed
pub fn unrealized_funding(&self, pos: &Position) -> IFixed
Convenience method for computing a position’s unrealized funding.
Forwards to Position::unrealized_funding.
Sourceimpl MarketState
impl MarketState
Sourcepub fn new(
cum_funding_rate_long: IFixed,
cum_funding_rate_short: IFixed,
funding_last_upd_ms: u64,
premium_twap: IFixed,
premium_twap_last_upd_ms: u64,
spread_twap: IFixed,
spread_twap_last_upd_ms: u64,
gas_price_mean: IFixed,
gas_price_variance: IFixed,
gas_price_last_upd_ms: u64,
open_interest: IFixed,
fees_accrued: IFixed,
) -> Self
pub fn new( cum_funding_rate_long: IFixed, cum_funding_rate_short: IFixed, funding_last_upd_ms: u64, premium_twap: IFixed, premium_twap_last_upd_ms: u64, spread_twap: IFixed, spread_twap_last_upd_ms: u64, gas_price_mean: IFixed, gas_price_variance: IFixed, gas_price_last_upd_ms: u64, open_interest: IFixed, fees_accrued: IFixed, ) -> Self
Constructs a new MarketState.
Sourceimpl MarketState
impl MarketState
pub fn move_instance(self, address: Address) -> MoveInstance<Self>
pub fn type_(address: Address) -> MarketStateTypeTag