pub enum OrderType {
Standard,
FillOrKill,
PostOnly,
ImmediateOrCancel,
}Variants
Standard
FillOrKill
Mandates that the entire order size be filled in the current transaction. Otherwise, the order is canceled.
PostOnly
Mandates that the entire order not be filled at all in the current transaction. Otherwise, cancel the order.
ImmediateOrCancel
Mandates that maximal possible part of an order will be filled in the current transaction. The rest of the order canceled.