pub struct Orderbook {
pub id: UID,
pub counter: u64,
}Expand description
The orderbook doesn’t know the types of tokens traded, it assumes a correct management by the clearing house
Fields
id: UIDcounter: u64Number of limit orders placed on book, monotonically increases
Implementations
Sourceimpl Orderbook
impl Orderbook
pub fn move_instance(self, address: Address) -> MoveInstance<Self>
pub fn type_(address: Address) -> OrderbookTypeTag
Sourceimpl Orderbook
impl Orderbook
Sourcepub fn asks_dof_wrapper_type(
package: Address,
) -> FieldTypeTag<Wrapper<AsksMap>, ID>
pub fn asks_dof_wrapper_type( package: Address, ) -> FieldTypeTag<Wrapper<AsksMap>, ID>
Convenience function to build the type of an AsksMapDofWrapper.
Sourcepub fn bids_dof_wrapper_type(
package: Address,
) -> FieldTypeTag<Wrapper<BidsMap>, ID>
pub fn bids_dof_wrapper_type( package: Address, ) -> FieldTypeTag<Wrapper<BidsMap>, ID>
Convenience function to build the type of an BidsMapDofWrapper.