Position

Struct Position 

pub struct Position {
    pub collateral: IFixed,
    pub base_asset_amount: IFixed,
    pub quote_asset_notional_amount: IFixed,
    pub cum_funding_rate_long: IFixed,
    pub cum_funding_rate_short: IFixed,
    pub asks_quantity: IFixed,
    pub bids_quantity: IFixed,
    pub pending_orders: u64,
    pub maker_fee: IFixed,
    pub taker_fee: IFixed,
    pub initial_margin_ratio: IFixed,
}
Stores information about an open position

Fields

collateral: IFixed

Amount of allocated tokens (e.g., USD stables) backing this account’s position.

base_asset_amount: IFixed

The perpetual contract size, controlling the amount of exposure to the underlying asset. Positive implies long position and negative, short. Represented as a signed fixed-point number.

quote_asset_notional_amount: IFixed

The entry value for this position, including leverage. Represented as a signed fixed-point number.

cum_funding_rate_long: IFixed

Last long cumulative funding rate used to update this position. The market’s latest long cumulative funding rate minus this gives the funding rate this position must pay. This rate multiplied by this position’s value (base asset amount * market price) gives the total funding owed, which is deducted from the trader account’s margin. This debt is accounted for in margin ratio calculations, which may lead to liquidation. Represented as a signed fixed-point number.

cum_funding_rate_short: IFixed

Last short cumulative funding rate used to update this position. The market’s latest short cumulative funding rate minus this gives the funding rate this position must pay. This rate multiplied by this position’s value (base asset amount * market price) gives the total funding owed, which is deducted from the trader account’s margin. This debt is accounted for in margin ratio calculations, which may lead to liquidation. Represented as a signed fixed-point number.

asks_quantity: IFixed

Base asset amount resting in ask orders in the orderbook. Represented as a signed fixed-point number.

bids_quantity: IFixed

Base asset amount resting in bid orders in the orderbook. Represented as a signed fixed-point number.

pending_orders: u64

Number of pending orders in this position.

maker_fee: IFixed

Custom maker fee for this position, set at default value of 100%

taker_fee: IFixed

Custom taker fee for this position, set at default value of 100%

initial_margin_ratio: IFixed

Initial Margin Ratio set by user for the position. Must always be less or equal than market’s IMR. Used as a desired reference margin ratio when managing collateral in the position during all the actions. Can be changed by the user at any moment (between the allowed limits).

Implementations

Source

impl Position

pub fn liquidation_price( &self, coll_price: IFixed, cum_funding_rate_long: IFixed, cum_funding_rate_short: IFixed, maintenance_margin_ratio: IFixed, ) -> Option<IFixed>

At which index price the position should be (partially) liquidated, assuming all the input variables stay the same.

pub fn entry_price(&self) -> Option<IFixed>

Entry price of the position’s contracts; in the same units as the oracle index price.

This function returns None if the position has no open contracts, i.e., if Self::base_asset_amount is zero.

pub fn unrealized_funding( &self, cum_funding_rate_long: IFixed, cum_funding_rate_short: IFixed, ) -> IFixed

The funding yet to be settled in this position given the market’s current cumulative fundings.

The return value is in the same quote currency that the index price uses. E.g., if the index price is USD/BTC, then the unrealized funding is in USD units.

pub fn unrealized_pnl(&self, price: IFixed) -> IFixed

Unrealized PnL given an index price.

The returned value is in the same currency as what the index price is quoted at. E.g., if the index price is a ratio of BTC/ETH, then the PnL is in BTC units.

pub fn notional(&self, price: IFixed) -> IFixed

Total position value used for risk calculations.

The returned value is in the same currency as what the index price is quoted at. E.g., if the index price is a ratio of BTC/ETH, then the PnL is in BTC units.

Source

impl Position

pub fn new( collateral: IFixed, base_asset_amount: IFixed, quote_asset_notional_amount: IFixed, cum_funding_rate_long: IFixed, cum_funding_rate_short: IFixed, asks_quantity: IFixed, bids_quantity: IFixed, pending_orders: u64, maker_fee: IFixed, taker_fee: IFixed, initial_margin_ratio: IFixed, ) -> Self

Constructs a new Position.

Source

impl Position

pub fn move_instance(self, address: Address) -> MoveInstance<Self>

pub fn type_(address: Address) -> PositionTypeTag