Module stop_orders

Module stop_orders 

Structs

StopOrderTicket
Object that allows to place one order on behalf of the user, used to offer stop limit or market orders. A stop order is an order that is placed only if the index price respects certain conditions, like being above or below a certain price.
StopOrderTicketTypeTag