StopOrderTicket

Struct StopOrderTicket 

pub struct StopOrderTicket<T: MoveType> {
    pub id: UID,
    pub executors: MoveVec<Address>,
    pub gas: Balance<SUI>,
    pub account_id: u64,
    pub stop_order_type: u64,
    pub encrypted_details: MoveVec<u8>,
    /* private fields */
}
Object that allows to place one order on behalf of the user, used to offer stop limit or market orders. A stop order is an order that is placed only if the index price respects certain conditions, like being above or below a certain price.

Only the AccountCap owner can mint this object and can decide who can be the executor of the ticket. This allows users to run their own stop orders bots eventually, but it’s mainly used to allow 3rd parties to offer such a service (the user is required to trust such 3rd party). The object is shared and the 3rd party is set as executors. The ticket can be destroyed in any moment only by the user or by the executor. The user needs to trust the 3rd party for liveness of the service offered.

The order details are encrypted offchain and the result is stored in the ticket. The user needs to share such details with the 3rd party only to allow for execution.

The ticket can be either a shared, owned or party object. The permission to execute or cancel it is controlled exclusively through executors, which can be modified only by the AccountCap owner associated with the ticket using the function edit_stop_order_ticket_executors.

Fields

id: UIDexecutors: MoveVec<Address>

Addresses allowed to execute the order on behalf of the user.

gas: Balance<SUI>

The executor collects the gas in case the order is placed or canceled for any reason. The user gets back the gas in case he manually cancels the order.

account_id: u64

User account id

stop_order_type: u64

Value to indentify the stop order type. Available values can be found in the constants module.

encrypted_details: MoveVec<u8>

Vector containing the blake2b hash obtained from offchain on the stop order parameters. Depending on the stop order type value, a different set of parameters is expected to be used.

Parameters encoded for a SLTP stop order (stop_order_type code 0):

  • clearing_house_id: ID
  • expire_timestamp: Option
  • is_limit_order: true if limit order, false if market order
  • stop_index_price: u256
  • is_stop_loss: true if stop loss order, false if take profit order
  • position_is_ask: true if position is short, false if position is long
  • size: u64
  • price: u64 (can be set at random value if is_limit_order is false)
  • order_type: u64 (can be set at random value if is_limit_order is false)
  • salt: vector

Parameters encoded for a Standalone stop order (stop_order_type code 1):

  • clearing_house_id: ID
  • expire_timestamp: Option
  • is_limit_order: true if limit order, false if market order
  • stop_index_price: u256
  • ge_stop_index_price: true means the order can be placed when oracle index price is >= than chosen stop_index_price
  • side: bool
  • size: u64
  • price: u64 (can be set at random value if is_limit_order is false)
  • order_type: u64 (can be set at random value if is_limit_order is false)
  • reduce_only: bool
  • salt: vector

Implementations

Source

impl<T: MoveType> StopOrderTicket<T>

pub fn new( id: UID, executors: MoveVec<Address>, gas: Balance<SUI>, account_id: u64, stop_order_type: u64, encrypted_details: MoveVec<u8>, ) -> Self

Constructs a new StopOrderTicket.

Source

impl<T: MoveType> StopOrderTicket<T>

pub fn move_instance( self, address: Address, t: <T as MoveType>::TypeTag, ) -> MoveInstance<Self>

pub fn type_( address: Address, t: <T as MoveType>::TypeTag, ) -> StopOrderTicketTypeTag<T>