pub struct SubAccount<T: MoveType> {
pub id: UID,
pub users: MoveVec<Address>,
pub account_id: u64,
pub collateral: Balance<T>,
/* private fields */
}Expand description
The SubAccount object represents a shared version of the Account object
with limited access to protocol’s features. Being a shared object, it can
only be used by the addresses specified in the users field.
Only the parent Account can withdraw Coin from a subaccount. The parent account is
required to specify a Sui address that will be able to use the subaccount on its behalf
and can change this address at any moment.
Subaccounts are used for trading and depositing, without running into race conditions, i.e., concurrent transactions using the same subaccount can be created and submitted (unlike accounts).
The created subaccount will share the primary’s account_id. That means it has access to the same positions of the primary.
The subaccount’s users are then able to:
- deposit collateral into the subaccount
- allocate collateral from subaccount to a clearing house
- use session to trade and liquidate on clearing house
- cancel pending orders
- deallocate from a clearing house to a subaccount
Fields
id: UIDusers: MoveVec<Address>Addresses able to make calls using this SubAccount
account_id: u64Numerical value associated to the parent account
collateral: Balance<T>Balance available to be allocated to markets.
Implementations
Sourceimpl<T: MoveType> SubAccount<T>
impl<T: MoveType> SubAccount<T>
Sourceimpl<T: MoveType> SubAccount<T>
impl<T: MoveType> SubAccount<T>
pub fn move_instance( self, address: Address, t: <T as MoveType>::TypeTag, ) -> MoveInstance<Self>
pub fn type_( address: Address, t: <T as MoveType>::TypeTag, ) -> SubAccountTypeTag<T>