pub struct StopOrderTicket<T: MoveType> {
pub id: UID,
pub user_address: Address,
pub expire_timestamp: u64,
pub encrypted_details: MoveVec<u8>,
/* private fields */
}Expand description
Object that allows to place one order on behalf of the user, used to offer stop limit or market orders. A stop order is an order that is placed only if the index price respects certain conditions, like being above or below a certain price.
Only the Account owner can mint this object and can decide who is
going to be the recipient of the ticket. This allows users to run their
own stop orders bots eventually, but it’s mainly used to allow 3rd parties
to offer such a service (the user is required to trust such 3rd party).
The object is intended to be sent to a multisig wallet owned by
both the 3rd party and the user. The object is not transferable, stopping
the 3rd party from transferring it away, and can be destroyed in any moment
only by the user. The user needs to trust the 3rd party for liveness of the
service offered.
The order details are encrypted offchain and the result is stored in the ticket. The user needs to share such details with the 3rd party only.
Fields
id: UIDuser_address: AddressSave user address. This allow only the user to cancel the ticket eventually.
expire_timestamp: u64Timestamp after which the order cannot be placed anymore
encrypted_details: MoveVec<u8>Vector containing the blake2b hash obtained by the offchain application of blake2b on the following parameters:
- clearing_house_id: ID
- account_id: u64
- is_limit_order:
trueif limit order,falseif market order - stop_index_price: u256
- ge_stop_index_price:
truemeans the order can be placed when oracle index price is >= than chosenstop_index_price - side: bool
- size: u64
- price: u64 (can be set at random value if
is_limit_orderis false) - order_type: u64 (can be set at random value if
is_limit_orderis false) - salt: vector
Implementations
Sourceimpl<T: MoveType> StopOrderTicket<T>
impl<T: MoveType> StopOrderTicket<T>
Sourceimpl<T: MoveType> StopOrderTicket<T>
impl<T: MoveType> StopOrderTicket<T>
pub fn move_instance( self, address: Address, t: <T as MoveType>::TypeTag, ) -> MoveInstance<Self>
pub fn type_( address: Address, t: <T as MoveType>::TypeTag, ) -> StopOrderTicketTypeTag<T>