Enums
Constants
- BadIndex
Price - Index price returned from oracle is 0 or invalid value
- Collateral
IsNot Registered - Collateral is not registered in the registry
- Deallocate
Target MrToo Low - Cannot compute deallocate amount for a target MR < IMR.
- Deposit
OrWithdraw Amount Zero - Cannot deposit/withdraw zero coins to/from the account’s collateral.
- Destroy
NotEmpty - When attempting to destroy a non-empty map
- Empty
Session - Raised when trying to have a session composed by only
start_sessionandend_session - Flag
Requirements Violated - Orderbook flag requirements violated
- Initial
Margin Requirement Violated - An operation brought an account below initial margin requirements.
- Insufficient
Free Collateral - Cannot withdraw more than the account’s free collateral.
- Insufficient
Insurance Surplus - Tried to withdraw more insurance funds than the allowed amount
- Invalid
Account ForStop Order - Invalid account trying to perform an action on a StopOrderTicket
- Invalid
Base Price Feed Storage - Invalid base price feed storage for the clearing house
- Invalid
Cancel Order Ids - Passed a vector of invalid order ids to cancel
- Invalid
Collateral Price Feed Storage - Invalid collateral price feed storage for the clearing house
- Invalid
Executor ForStop Order - Invalid executor trying to execute the StopOrderTicket
- Invalid
Force Cancel Ids - Passed a vector of invalid order ids to perform force cancellation during liquidation
- Invalid
MapParameters - While creating ordered map with wrong parameters.
- Invalid
Market Parameters - While creating ordered map with invalid parameters, or changing them improperly for an existent map.
- Invalid
Position ForSLTP - Invalid position’ status for placing a SLTP order
- Invalid
PositionIMR - Raised when trying to set a position’s IMR lower than market’s IMR or higher than 1
- Invalid
Proposal Delay - Margin ratio update proposal delay is outside the valid range
- Invalid
Size OrPrice - Orderbook size or price are invalid values
- Invalid
Stop Order Type - Invalid stop order type
- Invalid
SubAccount User - User trying to access the subaccount is not the one specified by parent
- Invalid
User ForOrder - Invalid user tries to modify an order
- KeyAlready
Exists - While inserting already existing key.
- KeyNot
Exist - While searching for a key, but it doesn’t exist.
- Liquidate
NotFirst Operation - Liquidate must be the first operation of the session, if performed.
- MapToo
Small - When trying to change a map configuration, but the map has length less than 4
- Market
Already Registered - Market already registered in the registry
- Market
IsNot Registered - Market is not registered in the registry
- MaxOpen
Interest Position Percent Surpassed - Raised when a position’s would get a base amount higher than the allowed percentage of open interest
- MaxOpen
Interest Surpassed - Raised when the market’s max open interest is surpassed as a result of the session’s actions
- MaxPending
Orders Exceeded - Tried placing a new pending order when the position already has the maximum allowed number of pending orders.
- Negative
Fees Accrued - Fees accrued are negative
- NoFees
Accrued - Exchange has no available fees to withdraw
- NoPrice
Feed ForMarket - Cannot create a market for which a price feed does not exist
- NotEnough
Collateral ToAllocate ForSession - Raised processing a session that requires a collateral allocation, but not enough collateral is available in the account or subaccount
- NotEnough
GasFor Stop Order - Stop order gas cost provided is not enough
- NotEnough
Liquidity - Minimum size matched not reached
- NotReduce
Only Stop Order - Reduce only conditions are not respected for stop order execution
- Order
UsdValue TooLow - Order value in USD is too low
- Position
AboveMMR - Position is above MMR, so can’t be liquidated.
- Position
Above Tolerance - When leaving liqee’s position with a margin ratio above tolerance, meaning that liqor has overbought position
- Position
Already Exists - Cannot have more than 1 position in a market.
- Position
BadDebt - Cannot realize bad debt via means other than calling ‘liquidate’.
- Position
BelowIMR - Used for checking both liqee and liqor positions during liquidation
- Premature
Proposal - Margin ratio update proposal cannot be commited too early
- Proposal
Already Exists - Margin ratio update proposal already exists for market
- Proposal
Already Matured - Cannot delete a proposal that already matured. It can only be committed.
- Proposal
Does NotExist - Margin ratio update proposal does not exist for market
- Self
Liquidation - Same liquidator and liqee account ids
- Self
Trading - When taker matches its own order
- Stop
Order Conditions Violated - Index price is not at correct value to satisfy stop order conditions
- Stop
Order Ticket Expired - Ticket has already passed
expire_timestampand can only be cancelled - Updating
Funding TooEarly - Tried to call
update_fundingbefore enough time has passed since the last update. - Wrong
Account IdFor Allocation - Raised processing a session that requires a collateral allocation and a wrong account or subaccount is being used to fund it
- Wrong
Order Details - Index price is not at correct value to satisfy stop order conditions
- Wrong
Parent ForSub Account - The parent
Accounttrying to delete the subaccount is not the correct one. - Wrong
Version - Raised when trying to call a function with the wrong package’s version