Index price returned from oracle is 0 or invalid value
Collateral is not registered in the registry
Cannot compute deallocate amount for a target MR < IMR.
Cannot deposit/withdraw zero coins to/from the account’s collateral.
When attempting to destroy a non-empty map
Raised when trying to have a session composed by only start_session and end_session
Orderbook flag requirements violated
An operation brought an account below initial margin requirements.
Cannot withdraw more than the account’s free collateral.
Tried to withdraw more insurance funds than the allowed amount
Invalid base price feed storage for the clearing house
Passed a vector of invalid order ids to cancel
Invalid collateral price feed storage for the clearing house
Passed a vector of invalid order ids to perform force cancellation
during liquidation
While creating ordered map with wrong parameters.
While creating ordered map with invalid parameters,
or changing them improperly for an existent map.
Margin ratio update proposal delay is outside the valid range
Orderbook size or price are invalid values
User trying to access the subaccount is not the one specified by parent
Invalid user tries to modify an order
While inserting already existing key.
While searching for a key, but it doesn’t exist.
Liquidate must be the first operation of the session, if performed.
When trying to change a map configuration, but the map has
length less than 4
Market already registered in the registry
Market is not registered in the registry
Tried placing a new pending order when the position already has the maximum
allowed number of pending orders.
Exchange has no available fees to withdraw
Cannot create a market for which a price feed does not exist
Minimum size matched not reached
Order value in USD is too low
Position is above MMR, so can’t be liquidated.
When leaving liqee’s position with a margin ratio above tolerance,
meaning that liqor has overbought position
Cannot have more than 1 position in a market.
Cannot realize bad debt via means other than calling ‘liquidate’.
Used for checking both liqee and liqor positions during liquidation
Margin ratio update proposal cannot be commited too early
Margin ratio update proposal already exists for market
Cannot delete a proposal that already matured. It can only be committed.
Margin ratio update proposal does not exist for market
Same liquidator and liqee account ids
When taker matches its own order
Index price is not at correct value to satisfy stop order conditions
Ticket has already passed expire_timestamp and can only be cancelled
Raised when trying to delete a subaccount still containing collateral.
Tried to call update_funding before enough time has passed since the
last update.
Index price is not at correct value to satisfy stop order conditions
The parent Account trying to delete the subaccount is not the correct one.
Raised when trying to call a function with the wrong package’s version