#[repr(u64)]pub enum MoveAbort {
Show 60 variants
DepositOrWithdrawAmountZero = 0,
InvalidSizeOrPrice = 1,
BadIndexPrice = 2,
OrderUsdValueTooLow = 4,
InvalidForceCancelIds = 5,
LiquidateNotFirstOperation = 6,
InvalidCancelOrderIds = 7,
StopOrderTicketExpired = 8,
StopOrderConditionsViolated = 9,
WrongOrderDetails = 10,
InvalidBasePriceFeedStorage = 11,
SelfLiquidation = 12,
InvalidSubAccountUser = 13,
WrongParentForSubAccount = 14,
WrongVersion = 16,
EmptySession = 17,
MarketAlreadyRegistered = 18,
CollateralIsNotRegistered = 19,
MarketIsNotRegistered = 20,
InvalidCollateralPriceFeedStorage = 21,
NegativeFeesAccrued = 22,
NotReduceOnlyStopOrder = 23,
NotEnoughGasForStopOrder = 24,
InvalidAccountForStopOrder = 26,
InvalidExecutorForStopOrder = 27,
MaxOpenInterestSurpassed = 28,
MaxOpenInterestPositionPercentSurpassed = 29,
NotEnoughCollateralToAllocateForSession = 30,
WrongAccountIdForAllocation = 31,
InvalidMarketParameters = 1_000,
UpdatingFundingTooEarly = 1_001,
ProposalAlreadyExists = 1_002,
PrematureProposal = 1_003,
InvalidProposalDelay = 1_004,
ProposalDoesNotExist = 1_005,
NoFeesAccrued = 1_006,
InsufficientInsuranceSurplus = 1_007,
NoPriceFeedForMarket = 1_008,
ProposalAlreadyMatured = 1_009,
MaxPendingOrdersExceeded = 2_000,
PositionBelowIMR = 2_001,
PositionAboveTolerance = 2_002,
InitialMarginRequirementViolated = 2_003,
PositionAboveMMR = 2_004,
PositionBadDebt = 2_005,
InsufficientFreeCollateral = 2_006,
PositionAlreadyExists = 2_007,
DeallocateTargetMrTooLow = 2_008,
InvalidPositionIMR = 2_009,
InvalidStopOrderType = 2_010,
InvalidPositionForSLTP = 2_011,
InvalidMapParameters = 3_000,
KeyNotExist = 3_001,
KeyAlreadyExists = 3_002,
DestroyNotEmpty = 3_003,
InvalidUserForOrder = 3_004,
FlagRequirementsViolated = 3_005,
NotEnoughLiquidity = 3_006,
MapTooSmall = 3_007,
SelfTrading = 3_008,
}Variants
DepositOrWithdrawAmountZero = 0
Cannot deposit/withdraw zero coins to/from the account’s collateral.
InvalidSizeOrPrice = 1
Orderbook size or price are invalid values
BadIndexPrice = 2
Index price returned from oracle is 0 or invalid value
OrderUsdValueTooLow = 4
Order value in USD is too low
InvalidForceCancelIds = 5
Passed a vector of invalid order ids to perform force cancellation during liquidation
LiquidateNotFirstOperation = 6
Liquidate must be the first operation of the session, if performed.
InvalidCancelOrderIds = 7
Passed a vector of invalid order ids to cancel
StopOrderTicketExpired = 8
Ticket has already passed expire_timestamp and can only be cancelled
StopOrderConditionsViolated = 9
Index price is not at correct value to satisfy stop order conditions
WrongOrderDetails = 10
Index price is not at correct value to satisfy stop order conditions
InvalidBasePriceFeedStorage = 11
Invalid base price feed storage for the clearing house
SelfLiquidation = 12
Same liquidator and liqee account ids
InvalidSubAccountUser = 13
User trying to access the subaccount is not the one specified by parent
WrongParentForSubAccount = 14
The parent Account trying to delete the subaccount is not the correct one.
WrongVersion = 16
Raised when trying to call a function with the wrong package’s version
EmptySession = 17
Raised when trying to have a session composed by only start_session and end_session
MarketAlreadyRegistered = 18
Market already registered in the registry
CollateralIsNotRegistered = 19
Collateral is not registered in the registry
MarketIsNotRegistered = 20
Market is not registered in the registry
InvalidCollateralPriceFeedStorage = 21
Invalid collateral price feed storage for the clearing house
NegativeFeesAccrued = 22
Fees accrued are negative
NotReduceOnlyStopOrder = 23
Reduce only conditions are not respected for stop order execution
NotEnoughGasForStopOrder = 24
Stop order gas cost provided is not enough
InvalidAccountForStopOrder = 26
Invalid account trying to perform an action on a StopOrderTicket
InvalidExecutorForStopOrder = 27
Invalid executor trying to execute the StopOrderTicket
MaxOpenInterestSurpassed = 28
Raised when the market’s max open interest is surpassed as a result of the session’s actions
MaxOpenInterestPositionPercentSurpassed = 29
Raised when a position’s would get a base amount higher than the allowed percentage of open interest
NotEnoughCollateralToAllocateForSession = 30
Raised processing a session that requires a collateral allocation, but not enough collateral is available in the account or subaccount
WrongAccountIdForAllocation = 31
Raised processing a session that requires a collateral allocation and a wrong account or subaccount is being used to fund it
InvalidMarketParameters = 1_000
While creating ordered map with invalid parameters, or changing them improperly for an existent map.
UpdatingFundingTooEarly = 1_001
Tried to call update_funding before enough time has passed since the
last update.
ProposalAlreadyExists = 1_002
Margin ratio update proposal already exists for market
PrematureProposal = 1_003
Margin ratio update proposal cannot be commited too early
InvalidProposalDelay = 1_004
Margin ratio update proposal delay is outside the valid range
ProposalDoesNotExist = 1_005
Margin ratio update proposal does not exist for market
NoFeesAccrued = 1_006
Exchange has no available fees to withdraw
InsufficientInsuranceSurplus = 1_007
Tried to withdraw more insurance funds than the allowed amount
NoPriceFeedForMarket = 1_008
Cannot create a market for which a price feed does not exist
ProposalAlreadyMatured = 1_009
Cannot delete a proposal that already matured. It can only be committed.
MaxPendingOrdersExceeded = 2_000
Tried placing a new pending order when the position already has the maximum allowed number of pending orders.
PositionBelowIMR = 2_001
Used for checking both liqee and liqor positions during liquidation
PositionAboveTolerance = 2_002
When leaving liqee’s position with a margin ratio above tolerance, meaning that liqor has overbought position
InitialMarginRequirementViolated = 2_003
An operation brought an account below initial margin requirements.
PositionAboveMMR = 2_004
Position is above MMR, so can’t be liquidated.
PositionBadDebt = 2_005
Cannot realize bad debt via means other than calling ‘liquidate’.
InsufficientFreeCollateral = 2_006
Cannot withdraw more than the account’s free collateral.
PositionAlreadyExists = 2_007
Cannot have more than 1 position in a market.
DeallocateTargetMrTooLow = 2_008
Cannot compute deallocate amount for a target MR < IMR.
InvalidPositionIMR = 2_009
Raised when trying to set a position’s IMR lower than market’s IMR or higher than 1
InvalidStopOrderType = 2_010
Invalid stop order type
InvalidPositionForSLTP = 2_011
Invalid position’ status for placing a SLTP order
InvalidMapParameters = 3_000
While creating ordered map with wrong parameters.
KeyNotExist = 3_001
While searching for a key, but it doesn’t exist.
KeyAlreadyExists = 3_002
While inserting already existing key.
DestroyNotEmpty = 3_003
When attempting to destroy a non-empty map
InvalidUserForOrder = 3_004
Invalid user tries to modify an order
FlagRequirementsViolated = 3_005
Orderbook flag requirements violated
NotEnoughLiquidity = 3_006
Minimum size matched not reached
MapTooSmall = 3_007
When trying to change a map configuration, but the map has length less than 4
SelfTrading = 3_008
When taker matches its own order
Implementations
Sourceimpl MoveAbort
impl MoveAbort
Sourcepub const fn is_deposit_or_withdraw_amount_zero(&self) -> bool
pub const fn is_deposit_or_withdraw_amount_zero(&self) -> bool
Returns true if the enum is MoveAbort::DepositOrWithdrawAmountZero otherwise false
Sourcepub const fn is_invalid_size_or_price(&self) -> bool
pub const fn is_invalid_size_or_price(&self) -> bool
Returns true if the enum is MoveAbort::InvalidSizeOrPrice otherwise false
Sourcepub const fn is_bad_index_price(&self) -> bool
pub const fn is_bad_index_price(&self) -> bool
Returns true if the enum is MoveAbort::BadIndexPrice otherwise false
Sourcepub const fn is_order_usd_value_too_low(&self) -> bool
pub const fn is_order_usd_value_too_low(&self) -> bool
Returns true if the enum is MoveAbort::OrderUsdValueTooLow otherwise false
Sourcepub const fn is_invalid_force_cancel_ids(&self) -> bool
pub const fn is_invalid_force_cancel_ids(&self) -> bool
Returns true if the enum is MoveAbort::InvalidForceCancelIds otherwise false
Sourcepub const fn is_liquidate_not_first_operation(&self) -> bool
pub const fn is_liquidate_not_first_operation(&self) -> bool
Returns true if the enum is MoveAbort::LiquidateNotFirstOperation otherwise false
Sourcepub const fn is_invalid_cancel_order_ids(&self) -> bool
pub const fn is_invalid_cancel_order_ids(&self) -> bool
Returns true if the enum is MoveAbort::InvalidCancelOrderIds otherwise false
Sourcepub const fn is_stop_order_ticket_expired(&self) -> bool
pub const fn is_stop_order_ticket_expired(&self) -> bool
Returns true if the enum is MoveAbort::StopOrderTicketExpired otherwise false
Sourcepub const fn is_stop_order_conditions_violated(&self) -> bool
pub const fn is_stop_order_conditions_violated(&self) -> bool
Returns true if the enum is MoveAbort::StopOrderConditionsViolated otherwise false
Sourcepub const fn is_wrong_order_details(&self) -> bool
pub const fn is_wrong_order_details(&self) -> bool
Returns true if the enum is MoveAbort::WrongOrderDetails otherwise false
Sourcepub const fn is_invalid_base_price_feed_storage(&self) -> bool
pub const fn is_invalid_base_price_feed_storage(&self) -> bool
Returns true if the enum is MoveAbort::InvalidBasePriceFeedStorage otherwise false
Sourcepub const fn is_self_liquidation(&self) -> bool
pub const fn is_self_liquidation(&self) -> bool
Returns true if the enum is MoveAbort::SelfLiquidation otherwise false
Sourcepub const fn is_invalid_sub_account_user(&self) -> bool
pub const fn is_invalid_sub_account_user(&self) -> bool
Returns true if the enum is MoveAbort::InvalidSubAccountUser otherwise false
Sourcepub const fn is_wrong_parent_for_sub_account(&self) -> bool
pub const fn is_wrong_parent_for_sub_account(&self) -> bool
Returns true if the enum is MoveAbort::WrongParentForSubAccount otherwise false
Sourcepub const fn is_wrong_version(&self) -> bool
pub const fn is_wrong_version(&self) -> bool
Returns true if the enum is MoveAbort::WrongVersion otherwise false
Sourcepub const fn is_empty_session(&self) -> bool
pub const fn is_empty_session(&self) -> bool
Returns true if the enum is MoveAbort::EmptySession otherwise false
Sourcepub const fn is_market_already_registered(&self) -> bool
pub const fn is_market_already_registered(&self) -> bool
Returns true if the enum is MoveAbort::MarketAlreadyRegistered otherwise false
Sourcepub const fn is_collateral_is_not_registered(&self) -> bool
pub const fn is_collateral_is_not_registered(&self) -> bool
Returns true if the enum is MoveAbort::CollateralIsNotRegistered otherwise false
Sourcepub const fn is_market_is_not_registered(&self) -> bool
pub const fn is_market_is_not_registered(&self) -> bool
Returns true if the enum is MoveAbort::MarketIsNotRegistered otherwise false
Sourcepub const fn is_invalid_collateral_price_feed_storage(&self) -> bool
pub const fn is_invalid_collateral_price_feed_storage(&self) -> bool
Returns true if the enum is MoveAbort::InvalidCollateralPriceFeedStorage otherwise false
Sourcepub const fn is_negative_fees_accrued(&self) -> bool
pub const fn is_negative_fees_accrued(&self) -> bool
Returns true if the enum is MoveAbort::NegativeFeesAccrued otherwise false
Sourcepub const fn is_not_reduce_only_stop_order(&self) -> bool
pub const fn is_not_reduce_only_stop_order(&self) -> bool
Returns true if the enum is MoveAbort::NotReduceOnlyStopOrder otherwise false
Sourcepub const fn is_not_enough_gas_for_stop_order(&self) -> bool
pub const fn is_not_enough_gas_for_stop_order(&self) -> bool
Returns true if the enum is MoveAbort::NotEnoughGasForStopOrder otherwise false
Sourcepub const fn is_invalid_account_for_stop_order(&self) -> bool
pub const fn is_invalid_account_for_stop_order(&self) -> bool
Returns true if the enum is MoveAbort::InvalidAccountForStopOrder otherwise false
Sourcepub const fn is_invalid_executor_for_stop_order(&self) -> bool
pub const fn is_invalid_executor_for_stop_order(&self) -> bool
Returns true if the enum is MoveAbort::InvalidExecutorForStopOrder otherwise false
Sourcepub const fn is_max_open_interest_surpassed(&self) -> bool
pub const fn is_max_open_interest_surpassed(&self) -> bool
Returns true if the enum is MoveAbort::MaxOpenInterestSurpassed otherwise false
Sourcepub const fn is_max_open_interest_position_percent_surpassed(&self) -> bool
pub const fn is_max_open_interest_position_percent_surpassed(&self) -> bool
Returns true if the enum is MoveAbort::MaxOpenInterestPositionPercentSurpassed otherwise false
Sourcepub const fn is_not_enough_collateral_to_allocate_for_session(&self) -> bool
pub const fn is_not_enough_collateral_to_allocate_for_session(&self) -> bool
Returns true if the enum is MoveAbort::NotEnoughCollateralToAllocateForSession otherwise false
Sourcepub const fn is_wrong_account_id_for_allocation(&self) -> bool
pub const fn is_wrong_account_id_for_allocation(&self) -> bool
Returns true if the enum is MoveAbort::WrongAccountIdForAllocation otherwise false
Sourcepub const fn is_invalid_market_parameters(&self) -> bool
pub const fn is_invalid_market_parameters(&self) -> bool
Returns true if the enum is MoveAbort::InvalidMarketParameters otherwise false
Sourcepub const fn is_updating_funding_too_early(&self) -> bool
pub const fn is_updating_funding_too_early(&self) -> bool
Returns true if the enum is MoveAbort::UpdatingFundingTooEarly otherwise false
Sourcepub const fn is_proposal_already_exists(&self) -> bool
pub const fn is_proposal_already_exists(&self) -> bool
Returns true if the enum is MoveAbort::ProposalAlreadyExists otherwise false
Sourcepub const fn is_premature_proposal(&self) -> bool
pub const fn is_premature_proposal(&self) -> bool
Returns true if the enum is MoveAbort::PrematureProposal otherwise false
Sourcepub const fn is_invalid_proposal_delay(&self) -> bool
pub const fn is_invalid_proposal_delay(&self) -> bool
Returns true if the enum is MoveAbort::InvalidProposalDelay otherwise false
Sourcepub const fn is_proposal_does_not_exist(&self) -> bool
pub const fn is_proposal_does_not_exist(&self) -> bool
Returns true if the enum is MoveAbort::ProposalDoesNotExist otherwise false
Sourcepub const fn is_no_fees_accrued(&self) -> bool
pub const fn is_no_fees_accrued(&self) -> bool
Returns true if the enum is MoveAbort::NoFeesAccrued otherwise false
Sourcepub const fn is_insufficient_insurance_surplus(&self) -> bool
pub const fn is_insufficient_insurance_surplus(&self) -> bool
Returns true if the enum is MoveAbort::InsufficientInsuranceSurplus otherwise false
Sourcepub const fn is_no_price_feed_for_market(&self) -> bool
pub const fn is_no_price_feed_for_market(&self) -> bool
Returns true if the enum is MoveAbort::NoPriceFeedForMarket otherwise false
Sourcepub const fn is_proposal_already_matured(&self) -> bool
pub const fn is_proposal_already_matured(&self) -> bool
Returns true if the enum is MoveAbort::ProposalAlreadyMatured otherwise false
Sourcepub const fn is_max_pending_orders_exceeded(&self) -> bool
pub const fn is_max_pending_orders_exceeded(&self) -> bool
Returns true if the enum is MoveAbort::MaxPendingOrdersExceeded otherwise false
Sourcepub const fn is_position_below_imr(&self) -> bool
pub const fn is_position_below_imr(&self) -> bool
Returns true if the enum is MoveAbort::PositionBelowIMR otherwise false
Sourcepub const fn is_position_above_tolerance(&self) -> bool
pub const fn is_position_above_tolerance(&self) -> bool
Returns true if the enum is MoveAbort::PositionAboveTolerance otherwise false
Sourcepub const fn is_initial_margin_requirement_violated(&self) -> bool
pub const fn is_initial_margin_requirement_violated(&self) -> bool
Returns true if the enum is MoveAbort::InitialMarginRequirementViolated otherwise false
Sourcepub const fn is_position_above_mmr(&self) -> bool
pub const fn is_position_above_mmr(&self) -> bool
Returns true if the enum is MoveAbort::PositionAboveMMR otherwise false
Sourcepub const fn is_position_bad_debt(&self) -> bool
pub const fn is_position_bad_debt(&self) -> bool
Returns true if the enum is MoveAbort::PositionBadDebt otherwise false
Sourcepub const fn is_insufficient_free_collateral(&self) -> bool
pub const fn is_insufficient_free_collateral(&self) -> bool
Returns true if the enum is MoveAbort::InsufficientFreeCollateral otherwise false
Sourcepub const fn is_position_already_exists(&self) -> bool
pub const fn is_position_already_exists(&self) -> bool
Returns true if the enum is MoveAbort::PositionAlreadyExists otherwise false
Sourcepub const fn is_deallocate_target_mr_too_low(&self) -> bool
pub const fn is_deallocate_target_mr_too_low(&self) -> bool
Returns true if the enum is MoveAbort::DeallocateTargetMrTooLow otherwise false
Sourcepub const fn is_invalid_position_imr(&self) -> bool
pub const fn is_invalid_position_imr(&self) -> bool
Returns true if the enum is MoveAbort::InvalidPositionIMR otherwise false
Sourcepub const fn is_invalid_stop_order_type(&self) -> bool
pub const fn is_invalid_stop_order_type(&self) -> bool
Returns true if the enum is MoveAbort::InvalidStopOrderType otherwise false
Sourcepub const fn is_invalid_position_for_sltp(&self) -> bool
pub const fn is_invalid_position_for_sltp(&self) -> bool
Returns true if the enum is MoveAbort::InvalidPositionForSLTP otherwise false
Sourcepub const fn is_invalid_map_parameters(&self) -> bool
pub const fn is_invalid_map_parameters(&self) -> bool
Returns true if the enum is MoveAbort::InvalidMapParameters otherwise false
Sourcepub const fn is_key_not_exist(&self) -> bool
pub const fn is_key_not_exist(&self) -> bool
Returns true if the enum is MoveAbort::KeyNotExist otherwise false
Sourcepub const fn is_key_already_exists(&self) -> bool
pub const fn is_key_already_exists(&self) -> bool
Returns true if the enum is MoveAbort::KeyAlreadyExists otherwise false
Sourcepub const fn is_destroy_not_empty(&self) -> bool
pub const fn is_destroy_not_empty(&self) -> bool
Returns true if the enum is MoveAbort::DestroyNotEmpty otherwise false
Sourcepub const fn is_invalid_user_for_order(&self) -> bool
pub const fn is_invalid_user_for_order(&self) -> bool
Returns true if the enum is MoveAbort::InvalidUserForOrder otherwise false
Sourcepub const fn is_flag_requirements_violated(&self) -> bool
pub const fn is_flag_requirements_violated(&self) -> bool
Returns true if the enum is MoveAbort::FlagRequirementsViolated otherwise false
Sourcepub const fn is_not_enough_liquidity(&self) -> bool
pub const fn is_not_enough_liquidity(&self) -> bool
Returns true if the enum is MoveAbort::NotEnoughLiquidity otherwise false
Sourcepub const fn is_map_too_small(&self) -> bool
pub const fn is_map_too_small(&self) -> bool
Returns true if the enum is MoveAbort::MapTooSmall otherwise false
Sourcepub const fn is_self_trading(&self) -> bool
pub const fn is_self_trading(&self) -> bool
Returns true if the enum is MoveAbort::SelfTrading otherwise false