#[non_exhaustive]pub enum EventInstance {
Show 74 variants
AcceptedPositionFeesProposal(MoveInstance<AcceptedPositionFeesProposal>),
AddedIntegratorConfig(MoveInstance<AddedIntegratorConfig<Otw>>),
AllocatedCollateral(MoveInstance<AllocatedCollateral>),
CanceledOrder(MoveInstance<CanceledOrder>),
ClosedMarket(MoveInstance<ClosedMarket>),
ClosedPositionAtSettlementPrices(MoveInstance<ClosedPositionAtSettlementPrices>),
CreatedAccount(MoveInstance<CreatedAccount<Otw>>),
CreatedAssistantAccountCap(MoveInstance<CreatedAssistantAccountCap>),
CreatedClearingHouse(MoveInstance<CreatedClearingHouse>),
CreatedIntegratorVault(MoveInstance<CreatedIntegratorVault>),
CreatedMarginRatiosProposal(MoveInstance<CreatedMarginRatiosProposal>),
CreatedOrderbook(MoveInstance<CreatedOrderbook>),
CreatedPosition(MoveInstance<CreatedPosition>),
CreatedPositionFeesProposal(MoveInstance<CreatedPositionFeesProposal>),
CreatedStopOrderTicket(MoveInstance<CreatedStopOrderTicket<Otw>>),
DeallocatedCollateral(MoveInstance<DeallocatedCollateral>),
DeletedMarginRatiosProposal(MoveInstance<DeletedMarginRatiosProposal>),
DeletedPositionFeesProposal(MoveInstance<DeletedPositionFeesProposal>),
DeletedStopOrderTicket(MoveInstance<DeletedStopOrderTicket<Otw>>),
DepositedCollateral(MoveInstance<DepositedCollateral<Otw>>),
DonatedToInsuranceFund(MoveInstance<DonatedToInsuranceFund>),
EditedStopOrderTicketDetails(MoveInstance<EditedStopOrderTicketDetails<Otw>>),
EditedStopOrderTicketExecutors(MoveInstance<EditedStopOrderTicketExecutors<Otw>>),
ExecutedStopOrderTicket(MoveInstance<ExecutedStopOrderTicket<Otw>>),
FilledMakerOrder(MoveInstance<FilledMakerOrder>),
FilledMakerOrders(MoveInstance<FilledMakerOrders>),
FilledTakerOrder(MoveInstance<FilledTakerOrder>),
LiquidatedPosition(MoveInstance<LiquidatedPosition>),
PaidIntegratorFees(MoveInstance<PaidIntegratorFees<Otw>>),
PausedMarket(MoveInstance<PausedMarket>),
PerformedADL(MoveInstance<PerformedADL>),
PerformedLiquidation(MoveInstance<PerformedLiquidation>),
PostedOrder(MoveInstance<PostedOrder>),
RegisteredCollateralInfo(MoveInstance<RegisteredCollateralInfo<Otw>>),
RegisteredMarketInfo(MoveInstance<RegisteredMarketInfo<Otw>>),
RejectedPositionFeesProposal(MoveInstance<RejectedPositionFeesProposal>),
RemovedIntegratorConfig(MoveInstance<RemovedIntegratorConfig<Otw>>),
RemovedRegisteredMarketInfo(MoveInstance<RemovedRegisteredMarketInfo<Otw>>),
ResettedPositionFees(MoveInstance<ResettedPositionFees>),
ResumedMarket(MoveInstance<ResumedMarket>),
RevokedAssistantAccountCap(MoveInstance<RevokedAssistantAccountCap>),
SetPositionInitialMarginRatio(MoveInstance<SetPositionInitialMarginRatio>),
SettledFunding(MoveInstance<SettledFunding>),
SocializedBadDebt(MoveInstance<SocializedBadDebt>),
UpdatedBasePfsID(MoveInstance<UpdatedBasePfsID>),
UpdatedBasePfsSourceID(MoveInstance<UpdatedBasePfsSourceID>),
UpdatedBasePfsTolerance(MoveInstance<UpdatedBasePfsTolerance>),
UpdatedClearingHouseVersion(MoveInstance<UpdatedClearingHouseVersion>),
UpdatedCollateralHaircut(MoveInstance<UpdatedCollateralHaircut>),
UpdatedCollateralPfsID(MoveInstance<UpdatedCollateralPfsID>),
UpdatedCollateralPfsSourceID(MoveInstance<UpdatedCollateralPfsSourceID>),
UpdatedCollateralPfsTolerance(MoveInstance<UpdatedCollateralPfsTolerance>),
UpdatedFees(MoveInstance<UpdatedFees>),
UpdatedFunding(MoveInstance<UpdatedFunding>),
UpdatedFundingParameters(MoveInstance<UpdatedFundingParameters>),
UpdatedGasPriceTwap(MoveInstance<UpdatedGasPriceTwap>),
UpdatedGasPriceTwapParameters(MoveInstance<UpdatedGasPriceTwapParameters>),
UpdatedMarginRatios(MoveInstance<UpdatedMarginRatios>),
UpdatedMarketLotAndTick(MoveInstance<UpdatedMarketLotAndTick>),
UpdatedMaxBadDebt(MoveInstance<UpdatedMaxBadDebt>),
UpdatedMaxOpenInterest(MoveInstance<UpdatedMaxOpenInterest>),
UpdatedMaxOpenInterestPositionParams(MoveInstance<UpdatedMaxOpenInterestPositionParams>),
UpdatedMaxPendingOrders(MoveInstance<UpdatedMaxPendingOrders>),
UpdatedMaxSocializeLossesMrDecrease(MoveInstance<UpdatedMaxSocializeLossesMrDecrease>),
UpdatedMinOrderUsdValue(MoveInstance<UpdatedMinOrderUsdValue>),
UpdatedOpenInterestAndFeesAccrued(MoveInstance<UpdatedOpenInterestAndFeesAccrued>),
UpdatedPremiumTwap(MoveInstance<UpdatedPremiumTwap>),
UpdatedSpreadTwap(MoveInstance<UpdatedSpreadTwap>),
UpdatedSpreadTwapParameters(MoveInstance<UpdatedSpreadTwapParameters>),
UpdatedStopOrderMistCost(MoveInstance<UpdatedStopOrderMistCost>),
WithdrewCollateral(MoveInstance<WithdrewCollateral<Otw>>),
WithdrewFees(MoveInstance<WithdrewFees>),
WithdrewFromIntegratorVault(MoveInstance<WithdrewFromIntegratorVault>),
WithdrewInsuranceFund(MoveInstance<WithdrewInsuranceFund>),
}Expand description
A Perpetuals event instance of any kind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AcceptedPositionFeesProposal(MoveInstance<AcceptedPositionFeesProposal>)
AddedIntegratorConfig(MoveInstance<AddedIntegratorConfig<Otw>>)
AllocatedCollateral(MoveInstance<AllocatedCollateral>)
CanceledOrder(MoveInstance<CanceledOrder>)
ClosedMarket(MoveInstance<ClosedMarket>)
ClosedPositionAtSettlementPrices(MoveInstance<ClosedPositionAtSettlementPrices>)
CreatedAccount(MoveInstance<CreatedAccount<Otw>>)
CreatedAssistantAccountCap(MoveInstance<CreatedAssistantAccountCap>)
CreatedClearingHouse(MoveInstance<CreatedClearingHouse>)
CreatedIntegratorVault(MoveInstance<CreatedIntegratorVault>)
CreatedMarginRatiosProposal(MoveInstance<CreatedMarginRatiosProposal>)
CreatedOrderbook(MoveInstance<CreatedOrderbook>)
CreatedPosition(MoveInstance<CreatedPosition>)
CreatedPositionFeesProposal(MoveInstance<CreatedPositionFeesProposal>)
CreatedStopOrderTicket(MoveInstance<CreatedStopOrderTicket<Otw>>)
DeallocatedCollateral(MoveInstance<DeallocatedCollateral>)
DeletedMarginRatiosProposal(MoveInstance<DeletedMarginRatiosProposal>)
DeletedPositionFeesProposal(MoveInstance<DeletedPositionFeesProposal>)
DeletedStopOrderTicket(MoveInstance<DeletedStopOrderTicket<Otw>>)
DepositedCollateral(MoveInstance<DepositedCollateral<Otw>>)
DonatedToInsuranceFund(MoveInstance<DonatedToInsuranceFund>)
EditedStopOrderTicketDetails(MoveInstance<EditedStopOrderTicketDetails<Otw>>)
EditedStopOrderTicketExecutors(MoveInstance<EditedStopOrderTicketExecutors<Otw>>)
ExecutedStopOrderTicket(MoveInstance<ExecutedStopOrderTicket<Otw>>)
FilledMakerOrder(MoveInstance<FilledMakerOrder>)
FilledMakerOrders(MoveInstance<FilledMakerOrders>)
FilledTakerOrder(MoveInstance<FilledTakerOrder>)
LiquidatedPosition(MoveInstance<LiquidatedPosition>)
PaidIntegratorFees(MoveInstance<PaidIntegratorFees<Otw>>)
PausedMarket(MoveInstance<PausedMarket>)
PerformedADL(MoveInstance<PerformedADL>)
PerformedLiquidation(MoveInstance<PerformedLiquidation>)
PostedOrder(MoveInstance<PostedOrder>)
RegisteredCollateralInfo(MoveInstance<RegisteredCollateralInfo<Otw>>)
RegisteredMarketInfo(MoveInstance<RegisteredMarketInfo<Otw>>)
RejectedPositionFeesProposal(MoveInstance<RejectedPositionFeesProposal>)
RemovedIntegratorConfig(MoveInstance<RemovedIntegratorConfig<Otw>>)
RemovedRegisteredMarketInfo(MoveInstance<RemovedRegisteredMarketInfo<Otw>>)
ResettedPositionFees(MoveInstance<ResettedPositionFees>)
ResumedMarket(MoveInstance<ResumedMarket>)
RevokedAssistantAccountCap(MoveInstance<RevokedAssistantAccountCap>)
SetPositionInitialMarginRatio(MoveInstance<SetPositionInitialMarginRatio>)
SettledFunding(MoveInstance<SettledFunding>)
SocializedBadDebt(MoveInstance<SocializedBadDebt>)
UpdatedBasePfsID(MoveInstance<UpdatedBasePfsID>)
UpdatedBasePfsSourceID(MoveInstance<UpdatedBasePfsSourceID>)
UpdatedBasePfsTolerance(MoveInstance<UpdatedBasePfsTolerance>)
UpdatedClearingHouseVersion(MoveInstance<UpdatedClearingHouseVersion>)
UpdatedCollateralHaircut(MoveInstance<UpdatedCollateralHaircut>)
UpdatedCollateralPfsID(MoveInstance<UpdatedCollateralPfsID>)
UpdatedCollateralPfsSourceID(MoveInstance<UpdatedCollateralPfsSourceID>)
UpdatedCollateralPfsTolerance(MoveInstance<UpdatedCollateralPfsTolerance>)
UpdatedFees(MoveInstance<UpdatedFees>)
UpdatedFunding(MoveInstance<UpdatedFunding>)
UpdatedFundingParameters(MoveInstance<UpdatedFundingParameters>)
UpdatedGasPriceTwap(MoveInstance<UpdatedGasPriceTwap>)
UpdatedGasPriceTwapParameters(MoveInstance<UpdatedGasPriceTwapParameters>)
UpdatedMarginRatios(MoveInstance<UpdatedMarginRatios>)
UpdatedMarketLotAndTick(MoveInstance<UpdatedMarketLotAndTick>)
UpdatedMaxBadDebt(MoveInstance<UpdatedMaxBadDebt>)
UpdatedMaxOpenInterest(MoveInstance<UpdatedMaxOpenInterest>)
UpdatedMaxOpenInterestPositionParams(MoveInstance<UpdatedMaxOpenInterestPositionParams>)
UpdatedMaxPendingOrders(MoveInstance<UpdatedMaxPendingOrders>)
UpdatedMaxSocializeLossesMrDecrease(MoveInstance<UpdatedMaxSocializeLossesMrDecrease>)
UpdatedMinOrderUsdValue(MoveInstance<UpdatedMinOrderUsdValue>)
UpdatedOpenInterestAndFeesAccrued(MoveInstance<UpdatedOpenInterestAndFeesAccrued>)
UpdatedPremiumTwap(MoveInstance<UpdatedPremiumTwap>)
UpdatedSpreadTwap(MoveInstance<UpdatedSpreadTwap>)
UpdatedSpreadTwapParameters(MoveInstance<UpdatedSpreadTwapParameters>)
UpdatedStopOrderMistCost(MoveInstance<UpdatedStopOrderMistCost>)
WithdrewCollateral(MoveInstance<WithdrewCollateral<Otw>>)
WithdrewFees(MoveInstance<WithdrewFees>)
WithdrewFromIntegratorVault(MoveInstance<WithdrewFromIntegratorVault>)
WithdrewInsuranceFund(MoveInstance<WithdrewInsuranceFund>)
Implementations
Sourceimpl EventInstance
impl EventInstance
Sourcepub const fn is_accepted_position_fees_proposal(&self) -> bool
pub const fn is_accepted_position_fees_proposal(&self) -> bool
Returns true if this value is of type AcceptedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_added_integrator_config(&self) -> bool
pub const fn is_added_integrator_config(&self) -> bool
Returns true if this value is of type AddedIntegratorConfig. Returns false otherwise
Sourcepub const fn is_allocated_collateral(&self) -> bool
pub const fn is_allocated_collateral(&self) -> bool
Returns true if this value is of type AllocatedCollateral. Returns false otherwise
Sourcepub const fn is_canceled_order(&self) -> bool
pub const fn is_canceled_order(&self) -> bool
Returns true if this value is of type CanceledOrder. Returns false otherwise
Sourcepub const fn is_closed_market(&self) -> bool
pub const fn is_closed_market(&self) -> bool
Returns true if this value is of type ClosedMarket. Returns false otherwise
Sourcepub const fn is_closed_position_at_settlement_prices(&self) -> bool
pub const fn is_closed_position_at_settlement_prices(&self) -> bool
Returns true if this value is of type ClosedPositionAtSettlementPrices. Returns false otherwise
Sourcepub const fn is_created_account(&self) -> bool
pub const fn is_created_account(&self) -> bool
Returns true if this value is of type CreatedAccount. Returns false otherwise
Sourcepub const fn is_created_assistant_account_cap(&self) -> bool
pub const fn is_created_assistant_account_cap(&self) -> bool
Returns true if this value is of type CreatedAssistantAccountCap. Returns false otherwise
Sourcepub const fn is_created_clearing_house(&self) -> bool
pub const fn is_created_clearing_house(&self) -> bool
Returns true if this value is of type CreatedClearingHouse. Returns false otherwise
Sourcepub const fn is_created_integrator_vault(&self) -> bool
pub const fn is_created_integrator_vault(&self) -> bool
Returns true if this value is of type CreatedIntegratorVault. Returns false otherwise
Sourcepub const fn is_created_margin_ratios_proposal(&self) -> bool
pub const fn is_created_margin_ratios_proposal(&self) -> bool
Returns true if this value is of type CreatedMarginRatiosProposal. Returns false otherwise
Sourcepub const fn is_created_orderbook(&self) -> bool
pub const fn is_created_orderbook(&self) -> bool
Returns true if this value is of type CreatedOrderbook. Returns false otherwise
Sourcepub const fn is_created_position(&self) -> bool
pub const fn is_created_position(&self) -> bool
Returns true if this value is of type CreatedPosition. Returns false otherwise
Sourcepub const fn is_created_position_fees_proposal(&self) -> bool
pub const fn is_created_position_fees_proposal(&self) -> bool
Returns true if this value is of type CreatedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_created_stop_order_ticket(&self) -> bool
pub const fn is_created_stop_order_ticket(&self) -> bool
Returns true if this value is of type CreatedStopOrderTicket. Returns false otherwise
Sourcepub const fn is_deallocated_collateral(&self) -> bool
pub const fn is_deallocated_collateral(&self) -> bool
Returns true if this value is of type DeallocatedCollateral. Returns false otherwise
Sourcepub const fn is_deleted_margin_ratios_proposal(&self) -> bool
pub const fn is_deleted_margin_ratios_proposal(&self) -> bool
Returns true if this value is of type DeletedMarginRatiosProposal. Returns false otherwise
Sourcepub const fn is_deleted_position_fees_proposal(&self) -> bool
pub const fn is_deleted_position_fees_proposal(&self) -> bool
Returns true if this value is of type DeletedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_deleted_stop_order_ticket(&self) -> bool
pub const fn is_deleted_stop_order_ticket(&self) -> bool
Returns true if this value is of type DeletedStopOrderTicket. Returns false otherwise
Sourcepub const fn is_deposited_collateral(&self) -> bool
pub const fn is_deposited_collateral(&self) -> bool
Returns true if this value is of type DepositedCollateral. Returns false otherwise
Sourcepub const fn is_donated_to_insurance_fund(&self) -> bool
pub const fn is_donated_to_insurance_fund(&self) -> bool
Returns true if this value is of type DonatedToInsuranceFund. Returns false otherwise
Sourcepub const fn is_edited_stop_order_ticket_details(&self) -> bool
pub const fn is_edited_stop_order_ticket_details(&self) -> bool
Returns true if this value is of type EditedStopOrderTicketDetails. Returns false otherwise
Sourcepub const fn is_edited_stop_order_ticket_executors(&self) -> bool
pub const fn is_edited_stop_order_ticket_executors(&self) -> bool
Returns true if this value is of type EditedStopOrderTicketExecutors. Returns false otherwise
Sourcepub const fn is_executed_stop_order_ticket(&self) -> bool
pub const fn is_executed_stop_order_ticket(&self) -> bool
Returns true if this value is of type ExecutedStopOrderTicket. Returns false otherwise
Sourcepub const fn is_filled_maker_order(&self) -> bool
pub const fn is_filled_maker_order(&self) -> bool
Returns true if this value is of type FilledMakerOrder. Returns false otherwise
Sourcepub const fn is_filled_maker_orders(&self) -> bool
pub const fn is_filled_maker_orders(&self) -> bool
Returns true if this value is of type FilledMakerOrders. Returns false otherwise
Sourcepub const fn is_filled_taker_order(&self) -> bool
pub const fn is_filled_taker_order(&self) -> bool
Returns true if this value is of type FilledTakerOrder. Returns false otherwise
Sourcepub const fn is_liquidated_position(&self) -> bool
pub const fn is_liquidated_position(&self) -> bool
Returns true if this value is of type LiquidatedPosition. Returns false otherwise
Sourcepub const fn is_paid_integrator_fees(&self) -> bool
pub const fn is_paid_integrator_fees(&self) -> bool
Returns true if this value is of type PaidIntegratorFees. Returns false otherwise
Sourcepub const fn is_paused_market(&self) -> bool
pub const fn is_paused_market(&self) -> bool
Returns true if this value is of type PausedMarket. Returns false otherwise
Sourcepub const fn is_performed_adl(&self) -> bool
pub const fn is_performed_adl(&self) -> bool
Returns true if this value is of type PerformedADL. Returns false otherwise
Sourcepub const fn is_performed_liquidation(&self) -> bool
pub const fn is_performed_liquidation(&self) -> bool
Returns true if this value is of type PerformedLiquidation. Returns false otherwise
Sourcepub const fn is_posted_order(&self) -> bool
pub const fn is_posted_order(&self) -> bool
Returns true if this value is of type PostedOrder. Returns false otherwise
Sourcepub const fn is_registered_collateral_info(&self) -> bool
pub const fn is_registered_collateral_info(&self) -> bool
Returns true if this value is of type RegisteredCollateralInfo. Returns false otherwise
Sourcepub const fn is_registered_market_info(&self) -> bool
pub const fn is_registered_market_info(&self) -> bool
Returns true if this value is of type RegisteredMarketInfo. Returns false otherwise
Sourcepub const fn is_rejected_position_fees_proposal(&self) -> bool
pub const fn is_rejected_position_fees_proposal(&self) -> bool
Returns true if this value is of type RejectedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_removed_integrator_config(&self) -> bool
pub const fn is_removed_integrator_config(&self) -> bool
Returns true if this value is of type RemovedIntegratorConfig. Returns false otherwise
Sourcepub const fn is_removed_registered_market_info(&self) -> bool
pub const fn is_removed_registered_market_info(&self) -> bool
Returns true if this value is of type RemovedRegisteredMarketInfo. Returns false otherwise
Sourcepub const fn is_resetted_position_fees(&self) -> bool
pub const fn is_resetted_position_fees(&self) -> bool
Returns true if this value is of type ResettedPositionFees. Returns false otherwise
Sourcepub const fn is_resumed_market(&self) -> bool
pub const fn is_resumed_market(&self) -> bool
Returns true if this value is of type ResumedMarket. Returns false otherwise
Sourcepub const fn is_revoked_assistant_account_cap(&self) -> bool
pub const fn is_revoked_assistant_account_cap(&self) -> bool
Returns true if this value is of type RevokedAssistantAccountCap. Returns false otherwise
Sourcepub const fn is_set_position_initial_margin_ratio(&self) -> bool
pub const fn is_set_position_initial_margin_ratio(&self) -> bool
Returns true if this value is of type SetPositionInitialMarginRatio. Returns false otherwise
Sourcepub const fn is_settled_funding(&self) -> bool
pub const fn is_settled_funding(&self) -> bool
Returns true if this value is of type SettledFunding. Returns false otherwise
Returns true if this value is of type SocializedBadDebt. Returns false otherwise
Sourcepub const fn is_updated_base_pfs_id(&self) -> bool
pub const fn is_updated_base_pfs_id(&self) -> bool
Returns true if this value is of type UpdatedBasePfsID. Returns false otherwise
Sourcepub const fn is_updated_base_pfs_source_id(&self) -> bool
pub const fn is_updated_base_pfs_source_id(&self) -> bool
Returns true if this value is of type UpdatedBasePfsSourceID. Returns false otherwise
Sourcepub const fn is_updated_base_pfs_tolerance(&self) -> bool
pub const fn is_updated_base_pfs_tolerance(&self) -> bool
Returns true if this value is of type UpdatedBasePfsTolerance. Returns false otherwise
Sourcepub const fn is_updated_clearing_house_version(&self) -> bool
pub const fn is_updated_clearing_house_version(&self) -> bool
Returns true if this value is of type UpdatedClearingHouseVersion. Returns false otherwise
Sourcepub const fn is_updated_collateral_haircut(&self) -> bool
pub const fn is_updated_collateral_haircut(&self) -> bool
Returns true if this value is of type UpdatedCollateralHaircut. Returns false otherwise
Sourcepub const fn is_updated_collateral_pfs_id(&self) -> bool
pub const fn is_updated_collateral_pfs_id(&self) -> bool
Returns true if this value is of type UpdatedCollateralPfsID. Returns false otherwise
Sourcepub const fn is_updated_collateral_pfs_source_id(&self) -> bool
pub const fn is_updated_collateral_pfs_source_id(&self) -> bool
Returns true if this value is of type UpdatedCollateralPfsSourceID. Returns false otherwise
Sourcepub const fn is_updated_collateral_pfs_tolerance(&self) -> bool
pub const fn is_updated_collateral_pfs_tolerance(&self) -> bool
Returns true if this value is of type UpdatedCollateralPfsTolerance. Returns false otherwise
Sourcepub const fn is_updated_fees(&self) -> bool
pub const fn is_updated_fees(&self) -> bool
Returns true if this value is of type UpdatedFees. Returns false otherwise
Sourcepub const fn is_updated_funding(&self) -> bool
pub const fn is_updated_funding(&self) -> bool
Returns true if this value is of type UpdatedFunding. Returns false otherwise
Sourcepub const fn is_updated_funding_parameters(&self) -> bool
pub const fn is_updated_funding_parameters(&self) -> bool
Returns true if this value is of type UpdatedFundingParameters. Returns false otherwise
Sourcepub const fn is_updated_gas_price_twap(&self) -> bool
pub const fn is_updated_gas_price_twap(&self) -> bool
Returns true if this value is of type UpdatedGasPriceTwap. Returns false otherwise
Sourcepub const fn is_updated_gas_price_twap_parameters(&self) -> bool
pub const fn is_updated_gas_price_twap_parameters(&self) -> bool
Returns true if this value is of type UpdatedGasPriceTwapParameters. Returns false otherwise
Sourcepub const fn is_updated_margin_ratios(&self) -> bool
pub const fn is_updated_margin_ratios(&self) -> bool
Returns true if this value is of type UpdatedMarginRatios. Returns false otherwise
Sourcepub const fn is_updated_market_lot_and_tick(&self) -> bool
pub const fn is_updated_market_lot_and_tick(&self) -> bool
Returns true if this value is of type UpdatedMarketLotAndTick. Returns false otherwise
Sourcepub const fn is_updated_max_bad_debt(&self) -> bool
pub const fn is_updated_max_bad_debt(&self) -> bool
Returns true if this value is of type UpdatedMaxBadDebt. Returns false otherwise
Sourcepub const fn is_updated_max_open_interest(&self) -> bool
pub const fn is_updated_max_open_interest(&self) -> bool
Returns true if this value is of type UpdatedMaxOpenInterest. Returns false otherwise
Sourcepub const fn is_updated_max_open_interest_position_params(&self) -> bool
pub const fn is_updated_max_open_interest_position_params(&self) -> bool
Returns true if this value is of type UpdatedMaxOpenInterestPositionParams. Returns false otherwise
Sourcepub const fn is_updated_max_pending_orders(&self) -> bool
pub const fn is_updated_max_pending_orders(&self) -> bool
Returns true if this value is of type UpdatedMaxPendingOrders. Returns false otherwise
Returns true if this value is of type UpdatedMaxSocializeLossesMrDecrease. Returns false otherwise
Sourcepub const fn is_updated_min_order_usd_value(&self) -> bool
pub const fn is_updated_min_order_usd_value(&self) -> bool
Returns true if this value is of type UpdatedMinOrderUsdValue. Returns false otherwise
Sourcepub const fn is_updated_open_interest_and_fees_accrued(&self) -> bool
pub const fn is_updated_open_interest_and_fees_accrued(&self) -> bool
Returns true if this value is of type UpdatedOpenInterestAndFeesAccrued. Returns false otherwise
Returns true if this value is of type UpdatedPremiumTwap. Returns false otherwise
Sourcepub const fn is_updated_spread_twap(&self) -> bool
pub const fn is_updated_spread_twap(&self) -> bool
Returns true if this value is of type UpdatedSpreadTwap. Returns false otherwise
Sourcepub const fn is_updated_spread_twap_parameters(&self) -> bool
pub const fn is_updated_spread_twap_parameters(&self) -> bool
Returns true if this value is of type UpdatedSpreadTwapParameters. Returns false otherwise
Sourcepub const fn is_updated_stop_order_mist_cost(&self) -> bool
pub const fn is_updated_stop_order_mist_cost(&self) -> bool
Returns true if this value is of type UpdatedStopOrderMistCost. Returns false otherwise
Sourcepub const fn is_withdrew_collateral(&self) -> bool
pub const fn is_withdrew_collateral(&self) -> bool
Returns true if this value is of type WithdrewCollateral. Returns false otherwise
Sourcepub const fn is_withdrew_fees(&self) -> bool
pub const fn is_withdrew_fees(&self) -> bool
Returns true if this value is of type WithdrewFees. Returns false otherwise
Sourcepub const fn is_withdrew_from_integrator_vault(&self) -> bool
pub const fn is_withdrew_from_integrator_vault(&self) -> bool
Returns true if this value is of type WithdrewFromIntegratorVault. Returns false otherwise
Sourcepub const fn is_withdrew_insurance_fund(&self) -> bool
pub const fn is_withdrew_insurance_fund(&self) -> bool
Returns true if this value is of type WithdrewInsuranceFund. Returns false otherwise
Sourceimpl EventInstance
impl EventInstance
pub fn new( type_: StructTag, bcs: impl AsRef<[u8]>, ) -> Result<Self, FromRawEventError>
pub fn struct_tag(&self) -> StructTag