#[non_exhaustive]pub enum EventInstance {
Show 53 variants
AcceptedPositionFeesProposal(MoveInstance<AcceptedPositionFeesProposal>),
AllocatedCollateral(MoveInstance<AllocatedCollateral>),
AllocatedCollateralSubAccount(MoveInstance<AllocatedCollateralSubAccount>),
CanceledOrder(MoveInstance<CanceledOrder>),
CanceledOrders(MoveInstance<CanceledOrders>),
CreatedAccount(MoveInstance<CreatedAccount<Otw>>),
CreatedClearingHouse(MoveInstance<CreatedClearingHouse>),
CreatedMarginRatiosProposal(MoveInstance<CreatedMarginRatiosProposal>),
CreatedOrderbook(MoveInstance<CreatedOrderbook>),
CreatedPosition(MoveInstance<CreatedPosition>),
CreatedPositionFeesProposal(MoveInstance<CreatedPositionFeesProposal>),
CreatedStopOrderTicket(MoveInstance<CreatedStopOrderTicket>),
CreatedSubAccount(MoveInstance<CreatedSubAccount>),
DeallocatedCollateral(MoveInstance<DeallocatedCollateral>),
DeallocatedCollateralSubAccount(MoveInstance<DeallocatedCollateralSubAccount>),
DeletedMarginRatiosProposal(MoveInstance<DeletedMarginRatiosProposal>),
DeletedPositionFeesProposal(MoveInstance<DeletedPositionFeesProposal>),
DeletedStopOrderTicket(MoveInstance<DeletedStopOrderTicket>),
DeletedSubAccount(MoveInstance<DeletedSubAccount>),
DepositedCollateral(MoveInstance<DepositedCollateral<Otw>>),
DepositedCollateralSubAccount(MoveInstance<DepositedCollateralSubAccount>),
DonatedToInsuranceFund(MoveInstance<DonatedToInsuranceFund>),
FilledMakerOrder(MoveInstance<FilledMakerOrder>),
FilledTakerOrder(MoveInstance<FilledTakerOrder>),
LiquidatedPosition(MoveInstance<LiquidatedPosition>),
OrderbookPostReceipt(MoveInstance<OrderbookPostReceipt>),
PostedOrder(MoveInstance<PostedOrder>),
RegisteredCollateralInfo(MoveInstance<RegisteredCollateralInfo<Otw>>),
RegisteredMarketInfo(MoveInstance<RegisteredMarketInfo<Otw>>),
RejectedPositionFeesProposal(MoveInstance<RejectedPositionFeesProposal>),
RemovedRegisteredMarketInfo(MoveInstance<RemovedRegisteredMarketInfo<Otw>>),
ResettedPositionFees(MoveInstance<ResettedPositionFees>),
SetSubAccountUser(MoveInstance<SetSubAccountUser>),
SettledFunding(MoveInstance<SettledFunding>),
UpdatedBaseOracleTolerance(MoveInstance<UpdatedBaseOracleTolerance>),
UpdatedClearingHouseVersion(MoveInstance<UpdatedClearingHouseVersion>),
UpdatedCollateralOracleTolerance(MoveInstance<UpdatedCollateralOracleTolerance>),
UpdatedCumFundings(MoveInstance<UpdatedCumFundings>),
UpdatedFees(MoveInstance<UpdatedFees>),
UpdatedFunding(MoveInstance<UpdatedFunding>),
UpdatedFundingParameters(MoveInstance<UpdatedFundingParameters>),
UpdatedLiquidationTolerance(MoveInstance<UpdatedLiquidationTolerance>),
UpdatedMarginRatios(MoveInstance<UpdatedMarginRatios>),
UpdatedMaxPendingOrders(MoveInstance<UpdatedMaxPendingOrders>),
UpdatedMinOrderUsdValue(MoveInstance<UpdatedMinOrderUsdValue>),
UpdatedOpenInterestAndFeesAccrued(MoveInstance<UpdatedOpenInterestAndFeesAccrued>),
UpdatedPremiumTwap(MoveInstance<UpdatedPremiumTwap>),
UpdatedSpreadTwap(MoveInstance<UpdatedSpreadTwap>),
UpdatedSpreadTwapParameters(MoveInstance<UpdatedSpreadTwapParameters>),
WithdrewCollateral(MoveInstance<WithdrewCollateral<Otw>>),
WithdrewCollateralSubAccount(MoveInstance<WithdrewCollateralSubAccount>),
WithdrewFees(MoveInstance<WithdrewFees>),
WithdrewInsuranceFund(MoveInstance<WithdrewInsuranceFund>),
}Expand description
A Perpetuals event instance of any kind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AcceptedPositionFeesProposal(MoveInstance<AcceptedPositionFeesProposal>)
AllocatedCollateral(MoveInstance<AllocatedCollateral>)
AllocatedCollateralSubAccount(MoveInstance<AllocatedCollateralSubAccount>)
CanceledOrder(MoveInstance<CanceledOrder>)
CanceledOrders(MoveInstance<CanceledOrders>)
CreatedAccount(MoveInstance<CreatedAccount<Otw>>)
CreatedClearingHouse(MoveInstance<CreatedClearingHouse>)
CreatedMarginRatiosProposal(MoveInstance<CreatedMarginRatiosProposal>)
CreatedOrderbook(MoveInstance<CreatedOrderbook>)
CreatedPosition(MoveInstance<CreatedPosition>)
CreatedPositionFeesProposal(MoveInstance<CreatedPositionFeesProposal>)
CreatedStopOrderTicket(MoveInstance<CreatedStopOrderTicket>)
CreatedSubAccount(MoveInstance<CreatedSubAccount>)
DeallocatedCollateral(MoveInstance<DeallocatedCollateral>)
DeallocatedCollateralSubAccount(MoveInstance<DeallocatedCollateralSubAccount>)
DeletedMarginRatiosProposal(MoveInstance<DeletedMarginRatiosProposal>)
DeletedPositionFeesProposal(MoveInstance<DeletedPositionFeesProposal>)
DeletedStopOrderTicket(MoveInstance<DeletedStopOrderTicket>)
DeletedSubAccount(MoveInstance<DeletedSubAccount>)
DepositedCollateral(MoveInstance<DepositedCollateral<Otw>>)
DepositedCollateralSubAccount(MoveInstance<DepositedCollateralSubAccount>)
DonatedToInsuranceFund(MoveInstance<DonatedToInsuranceFund>)
FilledMakerOrder(MoveInstance<FilledMakerOrder>)
FilledTakerOrder(MoveInstance<FilledTakerOrder>)
LiquidatedPosition(MoveInstance<LiquidatedPosition>)
OrderbookPostReceipt(MoveInstance<OrderbookPostReceipt>)
PostedOrder(MoveInstance<PostedOrder>)
RegisteredCollateralInfo(MoveInstance<RegisteredCollateralInfo<Otw>>)
RegisteredMarketInfo(MoveInstance<RegisteredMarketInfo<Otw>>)
RejectedPositionFeesProposal(MoveInstance<RejectedPositionFeesProposal>)
RemovedRegisteredMarketInfo(MoveInstance<RemovedRegisteredMarketInfo<Otw>>)
ResettedPositionFees(MoveInstance<ResettedPositionFees>)
SetSubAccountUser(MoveInstance<SetSubAccountUser>)
SettledFunding(MoveInstance<SettledFunding>)
UpdatedBaseOracleTolerance(MoveInstance<UpdatedBaseOracleTolerance>)
UpdatedClearingHouseVersion(MoveInstance<UpdatedClearingHouseVersion>)
UpdatedCollateralOracleTolerance(MoveInstance<UpdatedCollateralOracleTolerance>)
UpdatedCumFundings(MoveInstance<UpdatedCumFundings>)
UpdatedFees(MoveInstance<UpdatedFees>)
UpdatedFunding(MoveInstance<UpdatedFunding>)
UpdatedFundingParameters(MoveInstance<UpdatedFundingParameters>)
UpdatedLiquidationTolerance(MoveInstance<UpdatedLiquidationTolerance>)
UpdatedMarginRatios(MoveInstance<UpdatedMarginRatios>)
UpdatedMaxPendingOrders(MoveInstance<UpdatedMaxPendingOrders>)
UpdatedMinOrderUsdValue(MoveInstance<UpdatedMinOrderUsdValue>)
UpdatedOpenInterestAndFeesAccrued(MoveInstance<UpdatedOpenInterestAndFeesAccrued>)
UpdatedPremiumTwap(MoveInstance<UpdatedPremiumTwap>)
UpdatedSpreadTwap(MoveInstance<UpdatedSpreadTwap>)
UpdatedSpreadTwapParameters(MoveInstance<UpdatedSpreadTwapParameters>)
WithdrewCollateral(MoveInstance<WithdrewCollateral<Otw>>)
WithdrewCollateralSubAccount(MoveInstance<WithdrewCollateralSubAccount>)
WithdrewFees(MoveInstance<WithdrewFees>)
WithdrewInsuranceFund(MoveInstance<WithdrewInsuranceFund>)
Implementations
Sourceimpl EventInstance
impl EventInstance
Sourcepub const fn is_accepted_position_fees_proposal(&self) -> bool
pub const fn is_accepted_position_fees_proposal(&self) -> bool
Returns true if this value is of type AcceptedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_allocated_collateral(&self) -> bool
pub const fn is_allocated_collateral(&self) -> bool
Returns true if this value is of type AllocatedCollateral. Returns false otherwise
Sourcepub const fn is_allocated_collateral_sub_account(&self) -> bool
pub const fn is_allocated_collateral_sub_account(&self) -> bool
Returns true if this value is of type AllocatedCollateralSubAccount. Returns false otherwise
Sourcepub const fn is_canceled_order(&self) -> bool
pub const fn is_canceled_order(&self) -> bool
Returns true if this value is of type CanceledOrder. Returns false otherwise
Sourcepub const fn is_canceled_orders(&self) -> bool
pub const fn is_canceled_orders(&self) -> bool
Returns true if this value is of type CanceledOrders. Returns false otherwise
Sourcepub const fn is_created_account(&self) -> bool
pub const fn is_created_account(&self) -> bool
Returns true if this value is of type CreatedAccount. Returns false otherwise
Sourcepub const fn is_created_clearing_house(&self) -> bool
pub const fn is_created_clearing_house(&self) -> bool
Returns true if this value is of type CreatedClearingHouse. Returns false otherwise
Sourcepub const fn is_created_margin_ratios_proposal(&self) -> bool
pub const fn is_created_margin_ratios_proposal(&self) -> bool
Returns true if this value is of type CreatedMarginRatiosProposal. Returns false otherwise
Sourcepub const fn is_created_orderbook(&self) -> bool
pub const fn is_created_orderbook(&self) -> bool
Returns true if this value is of type CreatedOrderbook. Returns false otherwise
Sourcepub const fn is_created_position(&self) -> bool
pub const fn is_created_position(&self) -> bool
Returns true if this value is of type CreatedPosition. Returns false otherwise
Sourcepub const fn is_created_position_fees_proposal(&self) -> bool
pub const fn is_created_position_fees_proposal(&self) -> bool
Returns true if this value is of type CreatedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_created_stop_order_ticket(&self) -> bool
pub const fn is_created_stop_order_ticket(&self) -> bool
Returns true if this value is of type CreatedStopOrderTicket. Returns false otherwise
Sourcepub const fn is_created_sub_account(&self) -> bool
pub const fn is_created_sub_account(&self) -> bool
Returns true if this value is of type CreatedSubAccount. Returns false otherwise
Sourcepub const fn is_deallocated_collateral(&self) -> bool
pub const fn is_deallocated_collateral(&self) -> bool
Returns true if this value is of type DeallocatedCollateral. Returns false otherwise
Sourcepub const fn is_deallocated_collateral_sub_account(&self) -> bool
pub const fn is_deallocated_collateral_sub_account(&self) -> bool
Returns true if this value is of type DeallocatedCollateralSubAccount. Returns false otherwise
Sourcepub const fn is_deleted_margin_ratios_proposal(&self) -> bool
pub const fn is_deleted_margin_ratios_proposal(&self) -> bool
Returns true if this value is of type DeletedMarginRatiosProposal. Returns false otherwise
Sourcepub const fn is_deleted_position_fees_proposal(&self) -> bool
pub const fn is_deleted_position_fees_proposal(&self) -> bool
Returns true if this value is of type DeletedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_deleted_stop_order_ticket(&self) -> bool
pub const fn is_deleted_stop_order_ticket(&self) -> bool
Returns true if this value is of type DeletedStopOrderTicket. Returns false otherwise
Sourcepub const fn is_deleted_sub_account(&self) -> bool
pub const fn is_deleted_sub_account(&self) -> bool
Returns true if this value is of type DeletedSubAccount. Returns false otherwise
Sourcepub const fn is_deposited_collateral(&self) -> bool
pub const fn is_deposited_collateral(&self) -> bool
Returns true if this value is of type DepositedCollateral. Returns false otherwise
Sourcepub const fn is_deposited_collateral_sub_account(&self) -> bool
pub const fn is_deposited_collateral_sub_account(&self) -> bool
Returns true if this value is of type DepositedCollateralSubAccount. Returns false otherwise
Sourcepub const fn is_donated_to_insurance_fund(&self) -> bool
pub const fn is_donated_to_insurance_fund(&self) -> bool
Returns true if this value is of type DonatedToInsuranceFund. Returns false otherwise
Sourcepub const fn is_filled_maker_order(&self) -> bool
pub const fn is_filled_maker_order(&self) -> bool
Returns true if this value is of type FilledMakerOrder. Returns false otherwise
Sourcepub const fn is_filled_taker_order(&self) -> bool
pub const fn is_filled_taker_order(&self) -> bool
Returns true if this value is of type FilledTakerOrder. Returns false otherwise
Sourcepub const fn is_liquidated_position(&self) -> bool
pub const fn is_liquidated_position(&self) -> bool
Returns true if this value is of type LiquidatedPosition. Returns false otherwise
Sourcepub const fn is_orderbook_post_receipt(&self) -> bool
pub const fn is_orderbook_post_receipt(&self) -> bool
Returns true if this value is of type OrderbookPostReceipt. Returns false otherwise
Sourcepub const fn is_posted_order(&self) -> bool
pub const fn is_posted_order(&self) -> bool
Returns true if this value is of type PostedOrder. Returns false otherwise
Sourcepub const fn is_registered_collateral_info(&self) -> bool
pub const fn is_registered_collateral_info(&self) -> bool
Returns true if this value is of type RegisteredCollateralInfo. Returns false otherwise
Sourcepub const fn is_registered_market_info(&self) -> bool
pub const fn is_registered_market_info(&self) -> bool
Returns true if this value is of type RegisteredMarketInfo. Returns false otherwise
Sourcepub const fn is_rejected_position_fees_proposal(&self) -> bool
pub const fn is_rejected_position_fees_proposal(&self) -> bool
Returns true if this value is of type RejectedPositionFeesProposal. Returns false otherwise
Sourcepub const fn is_removed_registered_market_info(&self) -> bool
pub const fn is_removed_registered_market_info(&self) -> bool
Returns true if this value is of type RemovedRegisteredMarketInfo. Returns false otherwise
Sourcepub const fn is_resetted_position_fees(&self) -> bool
pub const fn is_resetted_position_fees(&self) -> bool
Returns true if this value is of type ResettedPositionFees. Returns false otherwise
Sourcepub const fn is_set_sub_account_user(&self) -> bool
pub const fn is_set_sub_account_user(&self) -> bool
Returns true if this value is of type SetSubAccountUser. Returns false otherwise
Sourcepub const fn is_settled_funding(&self) -> bool
pub const fn is_settled_funding(&self) -> bool
Returns true if this value is of type SettledFunding. Returns false otherwise
Sourcepub const fn is_updated_base_oracle_tolerance(&self) -> bool
pub const fn is_updated_base_oracle_tolerance(&self) -> bool
Returns true if this value is of type UpdatedBaseOracleTolerance. Returns false otherwise
Sourcepub const fn is_updated_clearing_house_version(&self) -> bool
pub const fn is_updated_clearing_house_version(&self) -> bool
Returns true if this value is of type UpdatedClearingHouseVersion. Returns false otherwise
Sourcepub const fn is_updated_collateral_oracle_tolerance(&self) -> bool
pub const fn is_updated_collateral_oracle_tolerance(&self) -> bool
Returns true if this value is of type UpdatedCollateralOracleTolerance. Returns false otherwise
Sourcepub const fn is_updated_cum_fundings(&self) -> bool
pub const fn is_updated_cum_fundings(&self) -> bool
Returns true if this value is of type UpdatedCumFundings. Returns false otherwise
Sourcepub const fn is_updated_fees(&self) -> bool
pub const fn is_updated_fees(&self) -> bool
Returns true if this value is of type UpdatedFees. Returns false otherwise
Sourcepub const fn is_updated_funding(&self) -> bool
pub const fn is_updated_funding(&self) -> bool
Returns true if this value is of type UpdatedFunding. Returns false otherwise
Sourcepub const fn is_updated_funding_parameters(&self) -> bool
pub const fn is_updated_funding_parameters(&self) -> bool
Returns true if this value is of type UpdatedFundingParameters. Returns false otherwise
Sourcepub const fn is_updated_liquidation_tolerance(&self) -> bool
pub const fn is_updated_liquidation_tolerance(&self) -> bool
Returns true if this value is of type UpdatedLiquidationTolerance. Returns false otherwise
Sourcepub const fn is_updated_margin_ratios(&self) -> bool
pub const fn is_updated_margin_ratios(&self) -> bool
Returns true if this value is of type UpdatedMarginRatios. Returns false otherwise
Sourcepub const fn is_updated_max_pending_orders(&self) -> bool
pub const fn is_updated_max_pending_orders(&self) -> bool
Returns true if this value is of type UpdatedMaxPendingOrders. Returns false otherwise
Sourcepub const fn is_updated_min_order_usd_value(&self) -> bool
pub const fn is_updated_min_order_usd_value(&self) -> bool
Returns true if this value is of type UpdatedMinOrderUsdValue. Returns false otherwise
Sourcepub const fn is_updated_open_interest_and_fees_accrued(&self) -> bool
pub const fn is_updated_open_interest_and_fees_accrued(&self) -> bool
Returns true if this value is of type UpdatedOpenInterestAndFeesAccrued. Returns false otherwise
Returns true if this value is of type UpdatedPremiumTwap. Returns false otherwise
Sourcepub const fn is_updated_spread_twap(&self) -> bool
pub const fn is_updated_spread_twap(&self) -> bool
Returns true if this value is of type UpdatedSpreadTwap. Returns false otherwise
Sourcepub const fn is_updated_spread_twap_parameters(&self) -> bool
pub const fn is_updated_spread_twap_parameters(&self) -> bool
Returns true if this value is of type UpdatedSpreadTwapParameters. Returns false otherwise
Sourcepub const fn is_withdrew_collateral(&self) -> bool
pub const fn is_withdrew_collateral(&self) -> bool
Returns true if this value is of type WithdrewCollateral. Returns false otherwise
Sourcepub const fn is_withdrew_collateral_sub_account(&self) -> bool
pub const fn is_withdrew_collateral_sub_account(&self) -> bool
Returns true if this value is of type WithdrewCollateralSubAccount. Returns false otherwise
Sourcepub const fn is_withdrew_fees(&self) -> bool
pub const fn is_withdrew_fees(&self) -> bool
Returns true if this value is of type WithdrewFees. Returns false otherwise
Sourcepub const fn is_withdrew_insurance_fund(&self) -> bool
pub const fn is_withdrew_insurance_fund(&self) -> bool
Returns true if this value is of type WithdrewInsuranceFund. Returns false otherwise
Sourceimpl EventInstance
impl EventInstance
pub fn new( type_: StructTag, bcs: impl AsRef<[u8]>, ) -> Result<Self, FromRawEventError>
pub fn struct_tag(&self) -> StructTag