Type Alias StopOrderTicket

pub type StopOrderTicket = StopOrderTicket<Otw>;

Aliased Type

struct StopOrderTicket {
    pub id: UID,
    pub gas: Balance<SUI>,
    pub account_id: u64,
    pub encrypted_details: MoveVec<u8>,
    /* private fields */
}

Fields

id: UIDgas: Balance<SUI>

Gas coin that must be provided by the user to cover for one stop order cost.

account_id: u64

Account id for user

encrypted_details: MoveVec<u8>

Vector containing the blake2b hash obtained by the offchain application of blake2b on the following parameters:

  • clearing_house_id: ID
  • expire_timestamp: u64
  • is_limit_order: true if limit order, false if market order
  • stop_index_price: u256
  • ge_stop_index_price: true means the order can be placed when oracle index price is >= than chosen stop_index_price
  • side: bool
  • size: u64
  • price: u64 (can be set at random value if is_limit_order is false)
  • order_type: u64 (can be set at random value if is_limit_order is false)
  • reduce_only: bool
  • salt: vector